@@ -1,7 +1,41 @@
 package Date::Holidays::BY;
-$Date::Holidays::BY::VERSION = '0.2018.0';
+
 # ABSTRACT: Determine Belorussian official holidays and business days.
 
+=encoding utf8
+
+=head1 NAME
+
+Date::Holidays::BY
+
+=head1 SYNOPSIS
+
+    use Date::Holidays::BY qw( is_holiday holidays is_business_day );
+
+    binmode STDOUT, ':encoding(UTF-8)';
+
+    my ( $year, $month, $day ) = ( localtime )[ 5, 4, 3 ];
+    $year  += 1900;
+    $month += 1;
+
+    if ( my $holidayname = is_holiday( $year, $month, $day ) ) {
+        print "Today is a holiday: $holidayname\n";
+    }
+
+    my $ref = holidays( $year );
+    while ( my ( $md, $name ) = each %$ref ) {
+        print "On $md there is a holiday named $name\n";
+    }
+
+    if ( is_business_day( 2012, 03, 11 ) ) {
+        print "2012-03-11 is business day on weekend\n";
+    }
+
+    if ( is_short_business_day( 2015, 04, 30 ) ) {
+        print "2015-04-30 is short business day\n";
+    }
+
+=cut
 
 use warnings;
 use strict;
@@ -21,16 +55,18 @@ use Time::Piece;
 use List::Util qw/ first /;
 
 
-my $HOLIDAYS_VALID_SINCE = 2017; # TODO
+my $HOLIDAYS_VALID_SINCE = 2017; # TODO add all old
 my $BUSINESS_DAYS_VALID_SINCE = 2017;
 
 # sources:
 #   https://ru.wikipedia.org/wiki/Праздники_Белоруссии
 
+# internal date formatting alike ISO 8601: MMDD
+
 my @REGULAR_HOLIDAYS = (
     {
         name => 'Новый год',
-		days => '0101',
+        days => '0101',
     },
     {
         name => 'Международный женский день',
@@ -60,26 +96,33 @@ my @REGULAR_HOLIDAYS = (
         name => 'Рождество Христово (католическое Рождество)',
         days => '1225',
     },
+    # Radonitsa - second tuesday after orthodox Easter - Easter is celebrated on the first Sunday after the spring full moon. The full moon is... oh no. Goes to HOLIDAYS_SPECIAL
 );
 
-
 my %HOLIDAYS_SPECIAL = (
     2017 => [ qw( 0102 0424 0425 0508 1106) ],
     2018 => [ qw( 0102 0309 0416 0417 0430 0702 1224 1231) ],
+    2019 => [ qw( 0506 0507 0508 1108) ],
 );
 
-
 my %BUSINESS_DAYS_ON_WEEKENDS = (
     2017 => [ qw( 0121 0429 0506 1104) ],
     2018 => [ qw( 0120 0303 0414 0428 0707 1222 1229) ],
+	2019 => [ qw( 0504 0511 1116) ],
 );
 
 my %SHORT_BUSINESS_DAYS = (
     2017 => [ qw( 0106 0307 0429 0506 1104) ],
     2018 => [ qw( 0307 0508 1106) ],
+    2019 => [ qw( 0307 0430 0506 0702 1106 1224) ],
 );
 
 
+=head2 is_holiday( $year, $month, $day )
+
+Determine whether this date is a BY holiday. Returns holiday name or undef.
+
+=cut
 
 sub is_holiday {
     my ( $year, $month, $day ) = @_;
@@ -89,11 +132,21 @@ sub is_holiday {
     return holidays( $year )->{ _get_date_key($month, $day) };
 }
 
+=head2 is_by_holiday( $year, $month, $day )
+
+Alias for is_holiday().
+
+=cut
 
 sub is_by_holiday {
     goto &is_holiday;
 }
 
+=head2 holidays( $year )
+
+Returns hash ref of all BY holidays in the year.
+
+=cut
 
 my %cache;
 sub holidays {
@@ -140,6 +193,11 @@ sub _resolve_yhash_value {
 }
 
 
+=head2 is_business_day( $year, $month, $day )
+
+Returns true if date is a business day in BY taking holidays and weekends into account.
+
+=cut
 
 sub is_business_day {
     my ( $year, $month, $day ) = @_;
@@ -164,6 +222,11 @@ sub is_business_day {
     return 0;
 }
 
+=head2 is_short_business_day( $year, $month, $day )
+
+Returns true if date is a shortened business day in BY.
+
+=cut
 
 sub is_short_business_day {
     my ( $year, $month, $day ) = @_;
@@ -180,91 +243,10 @@ sub _get_date_key {
     return sprintf '%02d%02d', $month, $day;
 }
 
-
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Date::Holidays::BY - Determine Belorussian official holidays and business days.
-
-=head1 VERSION
-
-version 0.2018.0
-
-=head1 SYNOPSIS
-
-    use Date::Holidays::BY qw( is_holiday holidays is_business_day );
-
-    binmode STDOUT, ':encoding(UTF-8)';
-   
-    my ( $year, $month, $day ) = ( localtime )[ 5, 4, 3 ];
-    $year  += 1900;
-    $month += 1;
-
-    if ( my $holidayname = is_holiday( $year, $month, $day ) ) {
-        print "Today is a holiday: $holidayname\n";
-    }
-    
-    my $ref = holidays( $year );
-    while ( my ( $md, $name ) = each %$ref ) {
-        print "On $md there is a holiday named $name\n";
-    }
-    
-    if ( is_business_day( 2012, 03, 11 ) ) {
-        print "2012-03-11 is business day on weekend\n";
-    }
-
-    if ( is_short_business_day( 2015, 04, 30 ) ) {
-        print "2015-04-30 is short business day\n";
-    }
-
-=head2 is_holiday( $year, $month, $day )
-
-Determine whether this date is a BY holiday. Returns holiday name or undef.
-
-=head2 is_by_holiday( $year, $month, $day )
-
-Alias for is_holiday().
-
-=head2 holidays( $year )
-
-Returns hash ref of all BY holidays in the year.
-
-=head2 is_business_day( $year, $month, $day )
-
-Returns true if date is a business day in BY taking holidays and weekends into account.
-
-=head2 is_short_business_day( $year, $month, $day )
-
-Returns true if date is a shortened business day in BY.
-
-=head1 NAME
-
-Date::Holidays::BY
-
-=head1 VERSION
-
-version 0.2018.0
-
 =head1 AUTHOR
 
 Vladimir Varlamov, C<< <bes.internal@gmail.com> >>
 
-=head1 AUTHOR
-
-Vladimir Varlamov <bes.internal@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by Vladimir Varlamov.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
+1;
